@@ -442,7 +442,7 @@ gdk_im_close (void)
     }
 }
 
-gint 
+gboolean
 gdk_im_ready (void)
 {
   return (xim_im != NULL);
@@ -1588,7 +1588,7 @@ gdk_mbstowcs (GdkWChar *dest, const gchar *src, gint dest_max)
       gint i;
 
       for (i=0; i<dest_max && src[i]; i++)
-	dest[i] = src[i];
+	dest[i] = (guchar)src[i];
 
       return i;
     }
