@@ -16,6 +16,14 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
+/*
+ * Modified by the GTK+ Team and others 1997-1999.  See the AUTHORS
+ * file for a list of people on the GTK+ Team.  See the ChangeLog
+ * files for a list of changes.  These files are distributed with
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ */
+
 #ifndef __GDK_PRIVATE_H__
 #define __GDK_PRIVATE_H__
 
@@ -138,6 +146,8 @@ struct _GdkFontPrivate
   gpointer xfont;
   Display *xdisplay;
   guint ref_count;
+
+  GSList *names;
 };
 
 struct _GdkCursorPrivate
