@@ -1240,7 +1240,7 @@ gdk_window_set_background (GdkWindow *window,
 void
 gdk_window_set_back_pixmap (GdkWindow *window,
 			    GdkPixmap *pixmap,
-			    gint       parent_relative)
+			    gboolean   parent_relative)
 {
   GdkWindowPrivate *window_private;
   GdkPixmapPrivate *pixmap_private;
@@ -2066,8 +2066,8 @@ gdk_window_set_icon (GdkWindow *window,
 }
 
 void          
-gdk_window_set_icon_name (GdkWindow *window, 
-			  gchar *    name)
+gdk_window_set_icon_name (GdkWindow   *window, 
+			  const gchar *name)
 {
   GdkWindowPrivate *window_private;
   XTextProperty property;
