@@ -23,7 +23,7 @@
  */
 
 /*
- * Modified by the GTK+ Team and others 1997-1999.  See the AUTHORS
+ * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
@@ -453,6 +453,7 @@ gtk_calendar_init (GtkCalendar *calendar)
   
   for (i=0;i<31;i++)
     calendar->marked_date[i] = FALSE;
+  calendar->num_marked_dates = 0;
   calendar->selected_day = 1;
   
   calendar->display_flags = ( GTK_CALENDAR_SHOW_HEADING | 
@@ -507,7 +508,7 @@ column_from_x (GtkCalendar *calendar,
       x_left = left_x_for_column (calendar, c);
       x_right = x_left + GTK_CALENDAR_PRIVATE_DATA (calendar)->day_width;
       
-      if (event_x > x_left && event_x < x_right)
+      if (event_x >= x_left && event_x < x_right)
 	{
 	  column = c;
 	  break;
@@ -544,7 +545,7 @@ row_from_y (GtkCalendar *calendar,
       y_top = top_y_for_row (calendar, r);
       y_bottom = y_top + height;
       
-      if (event_y > y_top && event_y < y_bottom)
+      if (event_y >= y_top && event_y < y_bottom)
 	{
 	  row = r;
 	  break;
@@ -661,11 +662,9 @@ gtk_calendar_set_month_prev (GtkCalendar *calendar)
     {
       if (calendar->selected_day < 0)
 	calendar->selected_day = calendar->selected_day + 1 + month_length[leap (calendar->year)][calendar->month + 1];
-      else
-	gtk_calendar_select_day (calendar, calendar->selected_day);
+      gtk_calendar_select_day (calendar, calendar->selected_day);
     }
   
-  gtk_calendar_select_day (calendar, calendar->selected_day);
   gtk_calendar_paint (GTK_WIDGET (calendar), NULL);
   gtk_calendar_thaw (calendar);
 }
@@ -793,6 +792,10 @@ gtk_calendar_main_button (GtkWidget	 *widget,
   
   row = row_from_y (calendar, y);
   col = column_from_x (calendar, x);
+
+  /* If row or column isn't found, just return. */
+  if (row == -1 || col == -1)
+    return;
   
   day_month = calendar->day_month[row][col];
   
@@ -2216,7 +2219,9 @@ gtk_calendar_clear_marks (GtkCalendar *calendar)
     {
       calendar->marked_date[day] = FALSE;
     }
-  
+ 
+  calendar->num_marked_dates = 0;
+ 
   if (GTK_WIDGET_DRAWABLE (calendar))
     {
       gtk_calendar_paint_main (GTK_WIDGET (calendar));
@@ -2230,9 +2235,11 @@ gtk_calendar_mark_day (GtkCalendar *calendar,
   g_return_val_if_fail (calendar != NULL, FALSE);
   g_return_val_if_fail (GTK_IS_CALENDAR (calendar), FALSE);
   
-  if (day >= 1 && day <= 31)
-    calendar->marked_date[day - 1] = TRUE;
-  
+  if (day >= 1 && day <= 31 && calendar->marked_date[day-1] == FALSE)
+    {
+      calendar->marked_date[day - 1] = TRUE;
+      calendar->num_marked_dates++;
+    }
   if (GTK_WIDGET_DRAWABLE (GTK_WIDGET (calendar)))
     {
       gtk_calendar_paint_main (GTK_WIDGET (calendar));
@@ -2248,8 +2255,11 @@ gtk_calendar_unmark_day (GtkCalendar *calendar,
   g_return_val_if_fail (calendar != NULL, FALSE);
   g_return_val_if_fail (GTK_IS_CALENDAR (calendar), FALSE);
   
-  if (day >= 1 && day <= 31)
-    calendar->marked_date[day - 1] = FALSE;
+  if (day >= 1 && day <= 31 && calendar->marked_date[day-1] == TRUE)
+    {
+      calendar->marked_date[day - 1] = FALSE;
+      calendar->num_marked_dates--;
+    }
   
   if (GTK_WIDGET_DRAWABLE (GTK_WIDGET (calendar)))
     {
